@@ -8,11 +8,12 @@ pop.index.plot<-function(rdata,xlim1,xlim2,xinc,ylim1,ylim2,yinc)
 
   year<-year(rdata$date[1])
   solvals<-seq(xlim1,xlim2,by=xinc)
-  dates<-solar.long_date(solvals,paste(year,"-01-01",sep=""),paste(year,"-12-31",sep=""))
+  dates<-solar.long_date(solvals,year)
   xlab2<-paste(day(dates),month.abb[month(dates)]," ",strftime(dates,format="%H:%M",tz="UTC"),sep="")
+  ind<-!is.na(rdata$pop.index)
   
   par(mar=c(5,4,6,3))
-  graph.data(rdata$sollong,rdata$pop.index,rdata$r.error,"Population index",xlim1,xlim2,xinc,ylim1,ylim2,yinc)
+  graph.data(rdata$sollong[ind],rdata$pop.index[ind],rdata$r.error[ind],"Population index",xlim1,xlim2,xinc,ylim1,ylim2,yinc)
   text(solvals,par("usr")[4],srt=45,xpd=TRUE,pos=4,offset=-0.1,labels=xlab2)
   mtext(paste("Time (UT,",year,")",sep=""),side=3,line=4,cex=1.2)
 }
\ No newline at end of file
