@@ -9,7 +9,7 @@ zhr.plot<-function(zhrdata,xlim1,xlim2,xinc,ylim1,ylim2,yinc)
  
  year<-year(zhrdata$date[1])
  solvals<-seq(xlim1,xlim2,by=xinc)
- dates<-solar.long_date(solvals,paste(year,"-01-01",sep=""),paste(year,"-12-31",sep=""))
+ dates<-solar.long_date(solvals,year)
  xlab2<-paste(day(dates),month.abb[month(dates)]," ",strftime(dates,format="%H:%M",tz="UTC"),sep="")
  
  par(mar=c(5,4,6,3))
